@@ -16,15 +16,21 @@ from typing import Any, cast
 from urllib.parse import parse_qs, urlencode
 
 import orjson
-from aiohttp import ClientConnectorError, ClientResponse, ClientSession, CookieJar
+from aiohttp import (
+    ClientConnectorError,
+    ClientResponse,
+    ClientSession,
+    ContentTypeError,
+)
 from bs4 import BeautifulSoup, Tag
-from langcodes import Language
+from langcodes import Language, standardize_tag
 from multidict import MultiDictProxy
 from yarl import URL
 
 from . import __version__
 from .const import (
     _LOGGER,
+    ALEXA_INFO_SKILLS,
     AMAZON_APP_BUNDLE_ID,
     AMAZON_APP_ID,
     AMAZON_APP_NAME,
@@ -37,23 +43,19 @@ from .const import (
     DEFAULT_AGENT,
     DEFAULT_ASSOC_HANDLE,
     DEFAULT_HEADERS,
+    DEFAULT_SITE,
     DEVICE_TO_IGNORE,
     DEVICE_TYPE_TO_MODEL,
-    DOMAIN_BY_ISO3166_COUNTRY,
     HTML_EXTENSION,
     HTTP_ERROR_199,
     HTTP_ERROR_299,
     JSON_EXTENSION,
-    NODE_BLUETOOTH,
-    NODE_DEVICES,
-    NODE_DO_NOT_DISTURB,
-    NODE_IDENTIFIER,
-    NODE_PREFERENCES,
+    REFRESH_ACCESS_TOKEN,
+    REFRESH_AUTH_COOKIES,
     SAVE_PATH,
     SENSORS,
-    URI_IDS,
-    URI_QUERIES,
-    URI_SENSORS,
+    URI_DEVICES,
+    URI_NEXUS_GRAPHQL,
     URI_SIGNIN,
 )
 from .exceptions import (
@@ -61,9 +63,9 @@ from .exceptions import (
     CannotConnect,
     CannotRegisterDevice,
     CannotRetrieveData,
-    WrongCountry,
     WrongMethod,
 )
+from .query import QUERY_DEVICE_STATE
 from .utils import obfuscate_email, scrub_fields
 
 
@@ -73,6 +75,7 @@ class AmazonDeviceSensor:
 
     name: str
     value: str | int | float
+    error: bool
     scale: str | None
 
 
@@ -86,15 +89,11 @@ class AmazonDevice:
     device_type: str
     device_owner_customer_id: str
     device_cluster_members: list[str]
-    device_locale: str
     online: bool
     serial_number: str
     software_version: str
-    do_not_disturb: bool
-    response_style: str | None
-    bluetooth_state: bool
-    entity_id: str
-    appliance_id: str
+    entity_id: str | None
+    endpoint_id: str | None
     sensors: dict[str, AmazonDeviceSensor]
 
 
@@ -121,50 +120,63 @@ class AmazonEchoApi:
 
     def __init__(
         self,
-        login_country_code: str,
+        client_session: ClientSession,
         login_email: str,
         login_password: str,
         login_data: dict[str, Any] | None = None,
-        save_raw_data: bool = False,
     ) -> None:
         """Initialize the scanner."""
-        # Force country digits as lower case
-        country_code = login_country_code.lower()
+        # Check if there is a previous login, otherwise use default (US)
+        site = login_data.get("site", DEFAULT_SITE) if login_data else DEFAULT_SITE
+        _LOGGER.debug("Using site: %s", site)
+        self._country_specific_data(site)
 
-        locale = DOMAIN_BY_ISO3166_COUNTRY.get(country_code, {})
-        domain = locale.get("domain", country_code)
-        market = locale.get("market", f"https://www.amazon.{domain}")
-        assoc_handle = locale.get(
-            "openid.assoc_handle", f"{DEFAULT_ASSOC_HANDLE}_{country_code}"
-        )
-
-        self._assoc_handle = assoc_handle
         self._login_email = login_email
         self._login_password = login_password
-        self._login_country_code = country_code
-        self._domain = domain
-        self._market = market
+
         self._cookies = self._build_init_cookies()
-        self._csrf_cookie: str | None = None
-        self._save_raw_data = save_raw_data
-        self._login_stored_data = login_data
+        self._save_raw_data = False
+        self._login_stored_data = login_data or {}
         self._serial = self._serial_number()
         self._list_for_clusters: dict[str, str] = {}
 
-        self.session: ClientSession
+        self._session = client_session
         self._devices: dict[str, Any] = {}
         self._sensors_available: bool = True
 
-        lang_object = Language.make(territory=self._login_country_code.upper())
+        _LOGGER.debug("Initialize library v%s", __version__)
+
+    @property
+    def domain(self) -> str:
+        """Return current Amazon domain."""
+        return self._domain
+
+    def save_raw_data(self) -> None:
+        """Save raw data to disk."""
+        self._save_raw_data = True
+        _LOGGER.debug("Saving raw data to disk")
+
+    def _country_specific_data(self, domain: str) -> None:
+        """Set country specific data."""
+        # Force lower case
+        domain = domain.replace("https://www.amazon.", "").lower()
+        country_code = domain.split(".")[-1] if domain != "com" else "us"
+
+        lang_object = Language.make(territory=country_code.upper())
         lang_maximized = lang_object.maximize()
-        self._language = f"{lang_maximized.language}-{lang_maximized.region}"
+
+        self._domain: str = domain
+        language = f"{lang_maximized.language}-{lang_maximized.territory}"
+        self._language = standardize_tag(language)
+
+        # Reset CSRF cookie when changing country
+        self._csrf_cookie: str | None = None
 
         _LOGGER.debug(
-            "Initialize library v%s: domain <amazon.%s>, language <%s>, market: <%s>",
-            __version__,
+            "Initialize country <%s>: domain <amazon.%s>, language <%s>",
+            country_code.upper(),
             self._domain,
             self._language,
-            self._market,
         )
 
     def _load_website_cookies(self) -> dict[str, str]:
@@ -241,11 +253,11 @@ class AmazonEchoApi:
         code_challenge = self._create_s256_code_challenge(code_verifier)
 
         oauth_params = {
-            "openid.return_to": f"https://www.amazon.{self._domain}/ap/maplanding",
+            "openid.return_to": "https://www.amazon.com/ap/maplanding",
             "openid.oa2.code_challenge_method": "S256",
-            "openid.assoc_handle": self._assoc_handle,
+            "openid.assoc_handle": DEFAULT_ASSOC_HANDLE,
             "openid.identity": "http://specs.openid.net/auth/2.0/identifier_select",
-            "pageId": self._assoc_handle,
+            "pageId": DEFAULT_ASSOC_HANDLE,
             "accountStatusPolicy": "P1",
             "openid.claimed_id": "http://specs.openid.net/auth/2.0/identifier_select",
             "openid.mode": "checkid_setup",
@@ -260,16 +272,14 @@ class AmazonEchoApi:
             "openid.oa2.response_type": "code",
         }
 
-        return (
-            f"https://www.amazon.{self._domain}{URI_SIGNIN}?{urlencode(oauth_params)}"
-        )
+        return f"https://www.amazon.com{URI_SIGNIN}?{urlencode(oauth_params)}"
 
     def _get_inputs_from_soup(self, soup: BeautifulSoup) -> dict[str, str]:
         """Extract hidden form input fields from a Amazon login page."""
         form = soup.find("form", {"name": "signIn"}) or soup.find("form")
 
         if not isinstance(form, Tag):
-            raise TypeError("Unable to find form in login response")
+            raise CannotAuthenticate("Unable to find form in login response")
 
         inputs = {}
         for field in form.find_all("input"):
@@ -287,7 +297,7 @@ class AmazonEchoApi:
             url = form.get("action")
             if isinstance(method, str) and isinstance(url, str):
                 return method, url
-        raise TypeError("Unable to extract form data from response")
+        raise CannotAuthenticate("Unable to extract form data from response")
 
     def _extract_code_from_url(self, url: URL) -> str:
         """Extract the access token from url query after login."""
@@ -298,17 +308,11 @@ class AmazonEchoApi:
             for key, value in url.query.items():
                 parsed_url[key] = [value]
         else:
-            raise TypeError(f"Unable to extract authorization code from url: {url}")
+            raise CannotAuthenticate(
+                f"Unable to extract authorization code from url: {url}"
+            )
         return parsed_url["openid.oa2.authorization_code"][0]
 
-    def _client_session(self) -> None:
-        """Create HTTP client session."""
-        if not hasattr(self, "session") or self.session.closed:
-            _LOGGER.debug("Creating HTTP session (aiohttp)")
-            cookie_jar = CookieJar()
-            cookie_jar.update_cookies(self._cookies)
-            self.session = ClientSession(cookie_jar=cookie_jar)
-
     async def _ignore_ap_signin_error(self, response: ClientResponse) -> bool:
         """Return true if error is due to signin endpoint."""
         # Endpoint URI_SIGNIN replies with error 404
@@ -320,14 +324,6 @@ class AmazonEchoApi:
             )
         return False
 
-    async def _ignore_phoenix_error(self, response: ClientResponse) -> bool:
-        """Return true if error is due to phoenix endpoint."""
-        # Endpoint URI_IDS replies with error 199 or 299
-        # during maintenance
-        return response.status in [HTTP_ERROR_199, HTTP_ERROR_299] and (
-            URI_IDS in response.url.path
-        )
-
     async def _http_phrase_error(self, error: int) -> str:
         """Convert numeric error in human phrase."""
         if error == HTTP_ERROR_199:
@@ -355,7 +351,7 @@ class AmazonEchoApi:
             json_data,
         )
 
-        headers = DEFAULT_HEADERS
+        headers = DEFAULT_HEADERS.copy()
         headers.update({"Accept-Language": self._language})
         if not amazon_user_agent:
             _LOGGER.debug("Changing User-Agent to %s", DEFAULT_AGENT)
@@ -373,7 +369,15 @@ class AmazonEchoApi:
         _cookies = (
             self._load_website_cookies() if self._login_stored_data else self._cookies
         )
-        self.session.cookie_jar.update_cookies(_cookies)
+        self._session.cookie_jar.update_cookies(_cookies, URL(f"amazon.{self._domain}"))
+
+        if url.endswith("/auth/token"):
+            headers.update(
+                {
+                    "Content-Type": "application/x-www-form-urlencoded",
+                    "x-amzn-identity-auth-domain": "api.amazon.com",
+                }
+            )
 
         resp: ClientResponse | None = None
         for delay in [0, 1, 2, 5, 8, 12, 21]:
@@ -384,7 +388,7 @@ class AmazonEchoApi:
                 await asyncio.sleep(delay)
 
             try:
-                resp = await self.session.request(
+                resp = await self._session.request(
                     method,
                     URL(url, encoded=True),
                     data=input_data if not json_data else orjson.dumps(input_data),
@@ -408,15 +412,18 @@ class AmazonEchoApi:
             _LOGGER.error("No response received from %s", url)
             raise CannotConnect(f"No response received from {url}")
 
-        if not self._csrf_cookie:
-            self._csrf_cookie = resp.cookies.get(CSRF_COOKIE, Morsel()).value
-            _LOGGER.debug("CSRF cookie value: <%s>", self._csrf_cookie)
+        if not self._csrf_cookie and (
+            csrf := resp.cookies.get(CSRF_COOKIE, Morsel()).value
+        ):
+            self._csrf_cookie = csrf
+            _LOGGER.debug("CSRF cookie value: <%s> [%s]", self._csrf_cookie, url)
 
         content_type: str = resp.headers.get("Content-Type", "")
         _LOGGER.debug(
-            "Response %s for url %s with content type: %s",
-            resp.status,
+            "Response for url %s :\nstatus      : %s \
+                                  \ncontent type: %s ",
             url,
+            resp.status,
             content_type,
         )
 
@@ -427,9 +434,7 @@ class AmazonEchoApi:
                 HTTPStatus.UNAUTHORIZED,
             ]:
                 raise CannotAuthenticate(await self._http_phrase_error(resp.status))
-            if not await self._ignore_ap_signin_error(
-                resp
-            ) and not await self._ignore_phoenix_error(resp):
+            if not await self._ignore_ap_signin_error(resp):
                 raise CannotRetrieveData(
                     f"Request failed: {await self._http_phrase_error(resp.status)}"
                 )
@@ -511,6 +516,7 @@ class AmazonEchoApi:
                 "software_version": AMAZON_DEVICE_SOFTWARE_VERSION,
             },
             "auth_data": {
+                "use_global_authentication": "true",
                 "client_id": self._build_client_id(),
                 "authorization_code": authorization_code,
                 "code_verifier": code_verifier.decode(),
@@ -526,16 +532,16 @@ class AmazonEchoApi:
             ],
         }
 
-        register_url = f"https://api.amazon.{self._domain}/auth/register"
-        _, resp = await self._session_request(
+        register_url = "https://api.amazon.com/auth/register"
+        _, raw_resp = await self._session_request(
             method=HTTPMethod.POST,
             url=register_url,
             input_data=body,
             json_data=True,
         )
-        resp_json = await resp.json()
+        resp_json = await self._response_to_json(raw_resp)
 
-        if resp.status != HTTPStatus.OK:
+        if raw_resp.status != HTTPStatus.OK:
             msg = resp_json["response"]["error"]["message"]
             _LOGGER.error(
                 "Cannot register device for %s: %s",
@@ -543,7 +549,7 @@ class AmazonEchoApi:
                 msg,
             )
             raise CannotRegisterDevice(
-                f"{await self._http_phrase_error(resp.status)}: {msg}"
+                f"{await self._http_phrase_error(raw_resp.status)}: {msg}"
             )
 
         success_response = resp_json["response"]["success"]
@@ -576,152 +582,97 @@ class AmazonEchoApi:
             "device_info": device_info,
             "customer_info": customer_info,
         }
-        await self._save_to_file(login_data, "login_data", JSON_EXTENSION)
+        _LOGGER.info("Register device: %s", scrub_fields(login_data))
         return login_data
 
-    async def _check_country(self) -> None:
-        """Check if user selected country matches Amazon account country."""
-        url = f"https://alexa.amazon.{self._domain}/api/users/me"
-        _, resp_me = await self._session_request(HTTPMethod.GET, url)
+    async def _get_devices_state(
+        self,
+    ) -> dict[str, Any]:
+        """Get Device State."""
+        payload = {
+            "operationName": "getDevicesState",
+            "variables": {
+                "latencyTolerance": "LOW",
+            },
+            "query": QUERY_DEVICE_STATE,
+        }
 
-        if resp_me.status != HTTPStatus.OK:
-            raise CannotAuthenticate
-
-        resp_me_json = await resp_me.json()
-        amazon_market = resp_me_json["marketPlaceDomainName"]
-
-        if amazon_market != self._market:
-            _LOGGER.warning(
-                "Selected country <%s> doesn't matches Amazon API reply:\n%s\n vs \n%s",
-                self._login_country_code.upper(),
-                {"input ": self._market},
-                {"amazon": amazon_market},
-            )
-            raise WrongCountry
-
-        _LOGGER.debug("User selected country matches Amazon API one")
-
-    async def _get_devices_ids(self) -> list[dict[str, str]]:
-        """Retrieve devices entityId and applianceId."""
         _, raw_resp = await self._session_request(
-            "GET",
-            url=f"https://alexa.amazon.{self._domain}{URI_IDS}",
-            amazon_user_agent=False,
-        )
-
-        # Sensors data not available
-        if raw_resp.status != HTTPStatus.OK:
-            _LOGGER.warning(
-                "Sensors data not available [%s error '%s'], skipping",
-                URI_IDS,
-                await self._http_phrase_error(raw_resp.status),
-            )
-            self._sensors_available = False
-            return []
-
-        json_data = await raw_resp.json()
-
-        network_detail = orjson.loads(json_data["networkDetail"])
-        # Navigate through the nested structure step by step
-        location_details = network_detail["locationDetails"]["locationDetails"]
-        default_location = location_details["Default_Location"]
-        amazon_bridge = default_location["amazonBridgeDetails"]["amazonBridgeDetails"]
-
-        # New devices are based on LambdaBridge_AAA structure
-        lambda_bridge_aaa = amazon_bridge.get("LambdaBridge_AAA/SonarCloudService")
-        appliance_details_aaa = (
-            lambda_bridge_aaa["applianceDetails"]["applianceDetails"]
-            if lambda_bridge_aaa
-            else {}
-        )
-
-        entity_ids_list: list[dict[str, str]] = await self._get_entities_ids(
-            appliance_details_aaa, "AAA_SonarCloudService"
-        )
-
-        # Old devices are based on LambdaBridge_AlexaBridge structure
-        for bridge_key, bridge_value in amazon_bridge.items():
-            if "LambdaBridge_AlexaBridge/" in bridge_key:
-                # Value key:    "LambdaBridge_AlexaBridge/XXXXXXXXXXXXXX@XXXXXXXXXXXXXX"
-                # Value subkey: "AlexaBridge_XXXXXXXXXXXXXX@XXXXXXXXXXXXXX_XXXXXXXXXXXX"
-                subkey = bridge_key.split("_")[1].replace("/", "_")
-
-                appliance_details_alexa = bridge_value["applianceDetails"][
-                    "applianceDetails"
-                ]
-                entity_ids_list.extend(
-                    await self._get_entities_ids(appliance_details_alexa, subkey)
-                )
-
-        return entity_ids_list
-
-    async def _get_entities_ids(
-        self, appliance_details: dict[str, Any], searchkey: str
-    ) -> list[dict[str, str]]:
-        """Extract entityId and applianceId."""
-        entity_ids_list: list[dict[str, str]] = []
-        # Process each appliance that starts with "searchkey"
-        for appliance_key, appliance_data in appliance_details.items():
-            if not appliance_key.startswith(searchkey):
-                continue
-
-            entity_id = appliance_data["entityId"]
-            appliance_id = appliance_data["applianceId"]
-
-            # Create identifier object for this appliance
-            identifier = {
-                "entityId": entity_id,
-                "applianceId": appliance_id,
-            }
-
-            # Update device information for each device in the identifier list
-            for device_identifier in appliance_data["alexaDeviceIdentifierList"]:
-                serial_number = device_identifier["dmsDeviceSerialNumber"]
-
-                # Add identifier information to the device
-                # but only if the device was previously found
-                if serial_number in self._devices:
-                    self._devices[serial_number] |= {NODE_IDENTIFIER: identifier}
-
-            # Add to entity IDs list for sensor retrieval
-            entity_ids_list.append({"entityId": entity_id, "entityType": "ENTITY"})
-
-        return entity_ids_list
-
-    async def _get_sensors_states(
-        self, entity_ids_list: list[dict[str, str]]
-    ) -> dict[str, dict[str, AmazonDeviceSensor]]:
-        """Retrieve devices sensors states."""
-        _data = {"stateRequests": entity_ids_list}
-        _, raw_resp = await self._session_request(
-            "POST",
-            url=f"https://alexa.amazon.{self._domain}{URI_SENSORS}",
-            input_data=_data,
+            method=HTTPMethod.POST,
+            url=f"https://alexa.amazon.{self._domain}{URI_NEXUS_GRAPHQL}",
+            input_data=payload,
             json_data=True,
         )
-        json_data = await raw_resp.json()
 
-        final_sensors: dict[str, dict[str, AmazonDeviceSensor]] = {}
-        for sensors in json_data["deviceStates"]:
-            _id = sensors["entity"]["entityId"]
-            dict_sensors: dict[str, AmazonDeviceSensor] = {}
-            for sensor in sensors["capabilityStates"]:
-                sensor_json = orjson.loads(sensor)
-                if sensor_json["name"] in SENSORS:
-                    _value = sensor_json["value"]
-                    _value_dict = isinstance(_value, dict)
-                    _name = sensor_json["name"]
-                    dict_sensors.update(
-                        {
-                            _name: AmazonDeviceSensor(
-                                name=_name,
-                                value=(_value["value"] if _value_dict else _value),
-                                scale=_value.get("scale") if _value_dict else None,
-                            )
-                        }
-                    )
-            final_sensors.update({_id: dict_sensors})
-        return final_sensors
+        return await self._response_to_json(raw_resp)
+
+    async def _get_sensors_states(
+        self,
+    ) -> tuple[dict[str, dict[str, Any]], dict[str, dict[str, AmazonDeviceSensor]]]:
+        """Retrieve devices sensors states."""
+        devices_state = await self._get_devices_state()
+        devices_sensors: dict[str, dict[str, AmazonDeviceSensor]] = {}
+        devices_endpoints: dict[str, dict[str, Any]] = {}
+
+        endpoints = devices_state["data"]["listEndpoints"]
+        for endpoint in endpoints.get("endpoints"):
+            serial_number = (
+                endpoint["serialNumber"]["value"]["text"]
+                if endpoint["serialNumber"]
+                else None
+            )
+            if serial_number in self._devices:
+                devices_sensors[serial_number] = self._get_device_sensor_state(endpoint)
+                devices_endpoints[serial_number] = endpoint
+
+        return devices_endpoints, devices_sensors
+
+    def _get_device_sensor_state(
+        self, endpoint: dict[str, Any]
+    ) -> dict[str, AmazonDeviceSensor]:
+        device_sensors: dict[str, AmazonDeviceSensor] = {}
+        if endpoint_dnd := endpoint.get("settings", {}).get("doNotDisturb"):
+            device_sensors["dnd"] = AmazonDeviceSensor(
+                name="dnd",
+                value=endpoint_dnd.get("toggleValue"),
+                error=bool(endpoint_dnd.get("error")),
+                scale=None,
+            )
+        for feature in endpoint.get("features", {}):
+            first_property = (feature.get("properties") or [None])[0] or {}
+            if (sensor := SENSORS.get(feature["name"])) is None:
+                # Skip sensors that are not in the predefined list
+                continue
+
+            if not (name := sensor["name"]):
+                raise CannotRetrieveData("Unable to read sensor template")
+
+            value = first_property[sensor["key"]]
+            scale = value["scale"] if sensor["scale"] else None
+            error = bool(sensor.get("error"))
+            if subkey := sensor["subkey"]:
+                value = value[subkey]
+            device_sensors[name] = AmazonDeviceSensor(
+                name,
+                value,
+                error,
+                scale,
+            )
+
+        return device_sensors
+
+    async def _response_to_json(self, raw_resp: ClientResponse) -> dict[str, Any]:
+        """Convert response to JSON, if possible."""
+        try:
+            data = await raw_resp.json(loads=orjson.loads)
+            if not data:
+                _LOGGER.warning("Empty JSON data received")
+                data = {}
+            return cast("dict[str, Any]", data)
+        except ContentTypeError as exc:
+            raise ValueError("Response not in JSON format") from exc
+        except orjson.JSONDecodeError as exc:
+            raise ValueError("Response with corrupted JSON format") from exc
 
     async def login_mode_interactive(self, otp_code: str) -> dict[str, Any]:
         """Login to Amazon interactively via OTP."""
@@ -730,8 +681,23 @@ class AmazonEchoApi:
             obfuscate_email(self._login_email),
             bool(otp_code),
         )
-        self._client_session()
 
+        device_login_data = await self._login_mode_interactive_oauth(otp_code)
+
+        login_data = await self._register_device(device_login_data)
+        self._login_stored_data = login_data
+
+        await self._domain_refresh_auth_cookies()
+
+        self._login_stored_data.update({"site": f"https://www.amazon.{self._domain}"})
+        await self._save_to_file(self._login_stored_data, "login_data", JSON_EXTENSION)
+
+        return self._login_stored_data
+
+    async def _login_mode_interactive_oauth(
+        self, otp_code: str
+    ) -> dict[str, str | bytes]:
+        """Login interactive via oauth URL."""
         code_verifier = self._create_code_verifier()
         client_id = self._build_client_id()
 
@@ -757,7 +723,7 @@ class AmazonEchoApi:
             _LOGGER.debug(
                 'Cannot find "auth-mfa-otpcode" in html source [%s]', login_url
             )
-            raise CannotAuthenticate
+            raise CannotAuthenticate("MFA OTP code not found on login page")
 
         login_method, login_url = self._get_request_from_soup(login_soup)
 
@@ -776,21 +742,12 @@ class AmazonEchoApi:
         authcode = self._extract_code_from_url(login_resp.url)
         _LOGGER.debug("Login extracted authcode: %s", authcode)
 
-        device_login_data = {
+        return {
             "authorization_code": authcode,
             "code_verifier": code_verifier,
             "domain": self._domain,
         }
 
-        register_device = await self._register_device(device_login_data)
-        self._login_stored_data = register_device
-
-        _LOGGER.info("Register device: %s", scrub_fields(register_device))
-
-        await self._check_country()
-
-        return register_device
-
     async def login_mode_stored_data(self) -> dict[str, Any]:
         """Login to Amazon using previously stored data."""
         if not self._login_stored_data:
@@ -805,89 +762,102 @@ class AmazonEchoApi:
             obfuscate_email(self._login_email),
         )
 
-        self._client_session()
-
-        await self._check_country()
+        # Check if session is still authenticated
+        if not await self.auth_check_status():
+            raise CannotAuthenticate("Session no longer authenticated")
 
         return self._login_stored_data
 
-    async def close(self) -> None:
-        """Close http client session."""
-        if hasattr(self, "session"):
-            _LOGGER.debug("Closing HTTP session (aiohttp)")
-            await self.session.close()
+    async def _get_alexa_domain(self) -> str:
+        """Get the Alexa domain."""
+        _LOGGER.debug("Retrieve Alexa domain")
+        _, raw_resp = await self._session_request(
+            method=HTTPMethod.GET,
+            url=f"https://alexa.amazon.{self._domain}/api/welcome",
+        )
+        json_data = await self._response_to_json(raw_resp)
+        return cast(
+            "str", json_data.get("alexaHostName", f"alexa.amazon.{self._domain}")
+        )
+
+    async def _refresh_auth_cookies(self) -> None:
+        """Refresh cookies after domain swap."""
+        _, json_token_resp = await self._refresh_data(REFRESH_AUTH_COOKIES)
+
+        # Need to take cookies from response and create them as cookies
+        website_cookies = self._login_stored_data["website_cookies"] = {}
+        self._session.cookie_jar.clear()
+
+        cookie_json = json_token_resp["response"]["tokens"]["cookies"]
+        for cookie_domain in cookie_json:
+            for cookie in cookie_json[cookie_domain]:
+                new_cookie_value = cookie["Value"].replace(r'"', r"")
+                new_cookie = {cookie["Name"]: new_cookie_value}
+                self._session.cookie_jar.update_cookies(new_cookie, URL(cookie_domain))
+                website_cookies.update(new_cookie)
+                if cookie["Name"] == "session-token":
+                    self._login_stored_data["store_authentication_cookie"] = {
+                        "cookie": new_cookie_value
+                    }
+
+    async def _domain_refresh_auth_cookies(self) -> None:
+        """Refresh cookies after domain swap."""
+        _LOGGER.debug("Refreshing auth cookies after domain change")
+
+        # Get the new Alexa domain
+        user_domain = (await self._get_alexa_domain()).replace("alexa", "https://www")
+        if user_domain != DEFAULT_SITE:
+            _LOGGER.debug("User domain changed to %s", user_domain)
+            self._country_specific_data(user_domain)
+            await self._refresh_auth_cookies()
 
     async def get_devices_data(
         self,
     ) -> dict[str, AmazonDevice]:
         """Get Amazon devices data."""
         self._devices = {}
-        for key in URI_QUERIES:
-            _, raw_resp = await self._session_request(
-                method=HTTPMethod.GET,
-                url=f"https://alexa.amazon.{self._domain}{URI_QUERIES[key]}",
-            )
-            _LOGGER.debug("Response URL: %s", raw_resp.url)
-            response_code = raw_resp.status
-            _LOGGER.debug("Response code: |%s|", response_code)
+        _, raw_resp = await self._session_request(
+            method=HTTPMethod.GET,
+            url=f"https://alexa.amazon.{self._domain}{URI_DEVICES}",
+        )
 
-            response_data = await raw_resp.text()
-            json_data = {} if len(response_data) == 0 else await raw_resp.json()
+        json_data = await self._response_to_json(raw_resp)
 
-            _LOGGER.debug("JSON data: |%s|", scrub_fields(json_data))
+        _LOGGER.debug("JSON devices data: %s", scrub_fields(json_data))
 
-            for data in json_data[key]:
-                dev_serial = data.get("serialNumber") or data.get("deviceSerialNumber")
-                if previous_data := self._devices.get(dev_serial):
-                    self._devices[dev_serial] = previous_data | {key: data}
-                else:
-                    self._devices[dev_serial] = {key: data}
+        for data in json_data["devices"]:
+            dev_serial = data.get("serialNumber")
+            self._devices[dev_serial] = data
 
-        devices_sensors: dict[str, dict[str, AmazonDeviceSensor]] = {}
-
-        if self._sensors_available and (
-            entity_ids_list := await self._get_devices_ids()
-        ):
-            devices_sensors = await self._get_sensors_states(entity_ids_list)
+        devices_endpoints, devices_sensors = await self._get_sensors_states()
 
         final_devices_list: dict[str, AmazonDevice] = {}
         for device in self._devices.values():
             # Remove stale, orphaned and virtual devices
-            devices_node = device.get(NODE_DEVICES)
-            if not devices_node or (devices_node.get("deviceType") in DEVICE_TO_IGNORE):
+            if not device or (device.get("deviceType") in DEVICE_TO_IGNORE):
                 continue
 
-            preferences_node = device.get(NODE_PREFERENCES, {})
-            do_not_disturb_node = device[NODE_DO_NOT_DISTURB]
-            bluetooth_node = device[NODE_BLUETOOTH]
-            identifier_node = device.get(NODE_IDENTIFIER, {})
-
+            serial_number: str = device["serialNumber"]
             # Add sensors
-            sensors = {}
-            if identifier_node:
-                for _device_id, _device_sensors in devices_sensors.items():
-                    if _device_id == identifier_node["entityId"]:
-                        sensors = _device_sensors
+            sensors = devices_sensors.get(serial_number, {})
+            device_endpoint = devices_endpoints.get(serial_number, {})
 
-            serial_number: str = devices_node["serialNumber"]
             final_devices_list[serial_number] = AmazonDevice(
-                account_name=devices_node["accountName"],
-                capabilities=devices_node["capabilities"],
-                device_family=devices_node["deviceFamily"],
-                device_type=devices_node["deviceType"],
-                device_owner_customer_id=devices_node["deviceOwnerCustomerId"],
-                device_cluster_members=(
-                    devices_node["clusterMembers"] or [serial_number]
-                ),
-                device_locale=preferences_node.get("locale", self._language),
-                online=devices_node["online"],
+                account_name=device["accountName"],
+                capabilities=device["capabilities"],
+                device_family=device["deviceFamily"],
+                device_type=device["deviceType"],
+                device_owner_customer_id=device["deviceOwnerCustomerId"],
+                device_cluster_members=(device["clusterMembers"] or [serial_number]),
+                online=device["online"],
                 serial_number=serial_number,
-                software_version=devices_node["softwareVersion"],
-                do_not_disturb=do_not_disturb_node["enabled"],
-                response_style=preferences_node.get("responseStyle"),
-                bluetooth_state=bluetooth_node["online"],
-                entity_id=identifier_node.get("entityId"),
-                appliance_id=identifier_node.get("applianceId"),
+                software_version=device["softwareVersion"],
+                entity_id=device_endpoint["legacyIdentifiers"]["chrsIdentifier"][
+                    "entityId"
+                ]
+                if device_endpoint
+                else None,
+                endpoint_id=device_endpoint["endpointId"] if device_endpoint else None,
                 sensors=sensors,
             )
 
@@ -913,7 +883,7 @@ class AmazonEchoApi:
             )
             return False
 
-        resp_json = await raw_resp.json()
+        resp_json = await self._response_to_json(raw_resp)
         if not (authentication := resp_json.get("authentication")):
             _LOGGER.debug('Session not authenticated: reply missing "authentication"')
             return False
@@ -945,13 +915,13 @@ class AmazonEchoApi:
     ) -> None:
         """Send message to specific device."""
         if not self._login_stored_data:
-            _LOGGER.warning("Trying to send message before login")
+            _LOGGER.warning("No login data available, cannot send message")
             return
 
         base_payload = {
             "deviceType": device.device_type,
             "deviceSerialNumber": device.serial_number,
-            "locale": device.device_locale,
+            "locale": self._language,
             "customerId": device.device_owner_customer_id,
         }
 
@@ -986,7 +956,7 @@ class AmazonEchoApi:
                 "expireAfter": "PT5S",
                 "content": [
                     {
-                        "locale": device.device_locale,
+                        "locale": self._language,
                         "display": {
                             "title": "Home Assistant",
                             "body": message_body,
@@ -1033,6 +1003,10 @@ class AmazonEchoApi:
                     "uri": "connection://AMAZON.Launch/" + message_body,
                 },
             }
+        elif message_type in ALEXA_INFO_SKILLS:
+            payload = {
+                **base_payload,
+            }
         else:
             raise ValueError(f"Message type <{message_type}> is not recognised")
 
@@ -1123,6 +1097,14 @@ class AmazonEchoApi:
             device, AmazonSequenceType.LaunchSkill, message_body
         )
 
+    async def call_alexa_info_skill(
+        self,
+        device: AmazonDevice,
+        message_type: str,
+    ) -> None:
+        """Call Info skill.  See ALEXA_INFO_SKILLS . const."""
+        return await self._send_message(device, message_type, "")
+
     async def set_do_not_disturb(self, device: AmazonDevice, state: bool) -> None:
         """Set do_not_disturb flag."""
         payload = {
@@ -1134,3 +1116,58 @@ class AmazonEchoApi:
         await self._session_request(
             method="PUT", url=url, input_data=payload, json_data=True
         )
+
+    async def _refresh_data(self, data_type: str) -> tuple[bool, dict]:
+        """Refresh data."""
+        if not self._login_stored_data:
+            _LOGGER.debug("No login data available, cannot refresh")
+            return False, {}
+
+        data = {
+            "app_name": AMAZON_APP_NAME,
+            "app_version": AMAZON_APP_VERSION,
+            "di.sdk.version": "6.12.4",
+            "source_token": self._login_stored_data["refresh_token"],
+            "package_name": AMAZON_APP_BUNDLE_ID,
+            "di.hw.version": "iPhone",
+            "platform": "iOS",
+            "requested_token_type": data_type,
+            "source_token_type": "refresh_token",
+            "di.os.name": "iOS",
+            "di.os.version": AMAZON_CLIENT_OS,
+            "current_version": "6.12.4",
+            "previous_version": "6.12.4",
+            "domain": f"www.amazon.{self._domain}",
+        }
+
+        raw_resp = await self._session.post(
+            "https://api.amazon.com/auth/token",
+            data=data,
+        )
+        _LOGGER.debug(
+            "Refresh data response %s with payload %s",
+            raw_resp.status,
+            orjson.dumps(data),
+        )
+
+        if raw_resp.status != HTTPStatus.OK:
+            _LOGGER.debug("Failed to refresh data")
+            return False, {}
+
+        json_response = await self._response_to_json(raw_resp)
+        _LOGGER.debug("Refresh data json:\n%s ", json_response)
+
+        if data_type == REFRESH_ACCESS_TOKEN and (
+            new_token := json_response.get(REFRESH_ACCESS_TOKEN)
+        ):
+            self._login_stored_data[REFRESH_ACCESS_TOKEN] = new_token
+            self.expires_in = datetime.now(tz=UTC).timestamp() + int(
+                json_response.get("expires_in", 0)
+            )
+            return True, json_response
+
+        if data_type == REFRESH_AUTH_COOKIES:
+            return True, json_response
+
+        _LOGGER.debug("Unexpected refresh data response")
+        return False, {}
